@@ -5,16 +5,16 @@ def main():
     b=sys.argv[2]
     c=sys.argv[3]
     if a=='sum':
-        r.sum(b,c)
+        print(r.sum(b,c))
     if a=='sub':
-        r.sub(b,c)
+        print(r.sub(b,c))
     if a=='mul':
-        r.mul(b,c)
+        print(r.mul(b,c))
     if a=='div':
-        r.div(b,c)
+        print(r.div(b,c))
     if a=='exp':
-        r.exp(b,c)
+        print(r.exp(b,c))
     if a=='complex':
-        r.complex(b,c)
+        print(r.complex(b,c))
 if __name__=='__main__':
     main()
